@@ -24,8 +24,7 @@ from typing import List, Optional
 from docopt import docopt
 
 from opensignals import __version__
-from opensignals.data import yahoo
-from opensignals.features import RSI
+from opensignals.data.yahoo import Yahoo
 
 
 def main(argv: Optional[List[str]] = None) -> None:
@@ -48,6 +47,7 @@ def main(argv: Optional[List[str]] = None) -> None:
         logging.basicConfig(level=logging.INFO)
 
     if args['download']:
+        yahoo = Yahoo()
         yahoo.download_data(Path(args['--dir']), args['--recreate'])
 
 
